# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.glossary_create_parameters import GlossaryCreateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestGlossaryCreateParameters(unittest.TestCase):
    """GlossaryCreateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GlossaryCreateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.glossary_create_parameters.GlossaryCreateParameters()  # noqa: E501
        if include_optional :
            return GlossaryCreateParameters(
                name = 'My glossary', 
                project_ids = 'abcd1234abcd1234abcd1234,abcd1234abcd1234abcd1235', 
                space_ids = ["abcd1234abcd1234abcd1234","abcd1234abcd1234abcd1235"]
            )
        else :
            return GlossaryCreateParameters(
        )

    def testGlossaryCreateParameters(self):
        """Test GlossaryCreateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
