# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class WebhookDelivery(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'webhook_id': 'str',
        'response_status_code': 'int',
        'delivered_at': 'datetime',
        'duration_ms': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'webhook_id': 'webhook_id',
        'response_status_code': 'response_status_code',
        'delivered_at': 'delivered_at',
        'duration_ms': 'duration_ms',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, webhook_id=None, response_status_code=None, delivered_at=None, duration_ms=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """WebhookDelivery - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._webhook_id = None
        self._response_status_code = None
        self._delivered_at = None
        self._duration_ms = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if webhook_id is not None:
            self.webhook_id = webhook_id
        if response_status_code is not None:
            self.response_status_code = response_status_code
        if delivered_at is not None:
            self.delivered_at = delivered_at
        if duration_ms is not None:
            self.duration_ms = duration_ms
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this WebhookDelivery.  # noqa: E501


        :return: The id of this WebhookDelivery.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookDelivery.


        :param id: The id of this WebhookDelivery.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookDelivery.  # noqa: E501


        :return: The webhook_id of this WebhookDelivery.  # noqa: E501
        :rtype: str
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookDelivery.


        :param webhook_id: The webhook_id of this WebhookDelivery.  # noqa: E501
        :type: str
        """

        self._webhook_id = webhook_id

    @property
    def response_status_code(self):
        """Gets the response_status_code of this WebhookDelivery.  # noqa: E501


        :return: The response_status_code of this WebhookDelivery.  # noqa: E501
        :rtype: int
        """
        return self._response_status_code

    @response_status_code.setter
    def response_status_code(self, response_status_code):
        """Sets the response_status_code of this WebhookDelivery.


        :param response_status_code: The response_status_code of this WebhookDelivery.  # noqa: E501
        :type: int
        """

        self._response_status_code = response_status_code

    @property
    def delivered_at(self):
        """Gets the delivered_at of this WebhookDelivery.  # noqa: E501


        :return: The delivered_at of this WebhookDelivery.  # noqa: E501
        :rtype: datetime
        """
        return self._delivered_at

    @delivered_at.setter
    def delivered_at(self, delivered_at):
        """Sets the delivered_at of this WebhookDelivery.


        :param delivered_at: The delivered_at of this WebhookDelivery.  # noqa: E501
        :type: datetime
        """

        self._delivered_at = delivered_at

    @property
    def duration_ms(self):
        """Gets the duration_ms of this WebhookDelivery.  # noqa: E501


        :return: The duration_ms of this WebhookDelivery.  # noqa: E501
        :rtype: int
        """
        return self._duration_ms

    @duration_ms.setter
    def duration_ms(self, duration_ms):
        """Sets the duration_ms of this WebhookDelivery.


        :param duration_ms: The duration_ms of this WebhookDelivery.  # noqa: E501
        :type: int
        """

        self._duration_ms = duration_ms

    @property
    def created_at(self):
        """Gets the created_at of this WebhookDelivery.  # noqa: E501


        :return: The created_at of this WebhookDelivery.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this WebhookDelivery.


        :param created_at: The created_at of this WebhookDelivery.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this WebhookDelivery.  # noqa: E501


        :return: The updated_at of this WebhookDelivery.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this WebhookDelivery.


        :param updated_at: The updated_at of this WebhookDelivery.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookDelivery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookDelivery):
            return True

        return self.to_dict() != other.to_dict()
