# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.uploads_api import UploadsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestUploadsApi(unittest.TestCase):
    """UploadsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.uploads_api.UploadsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_upload_create(self):
        """Test case for upload_create

        Upload a new file  # noqa: E501
        """
        pass

    def test_upload_show(self):
        """Test case for upload_show

        View upload details  # noqa: E501
        """
        pass

    def test_uploads_list(self):
        """Test case for uploads_list

        List uploads  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
