# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.variables_api import VariablesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestVariablesApi(unittest.TestCase):
    """VariablesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.variables_api.VariablesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_variable_create(self):
        """Test case for variable_create

        Create a variable  # noqa: E501
        """
        pass

    def test_variable_delete(self):
        """Test case for variable_delete

        Delete a variable  # noqa: E501
        """
        pass

    def test_variable_show(self):
        """Test case for variable_show

        Get a single variable  # noqa: E501
        """
        pass

    def test_variable_update(self):
        """Test case for variable_update

        Update a variable  # noqa: E501
        """
        pass

    def test_variables_list(self):
        """Test case for variables_list

        List variables  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
